@@ -59,6 +59,12 @@ NONVETO_STRUCT  = {
     'stimestamp'    : 36,
 }
 
+TGF_STRUCT={
+    'stimestamp': 48,
+    'channel': 2,
+    'adc_counts': 14,
+}
+
 ORBIT_UNITS     = ['(s)','(C)','(Hz)','(Hz)','(Hz)','(Hz)','(Hz)','(DAC ch)','(DAC ch)','(PMT 0 - SiPM 1)','(OFF 0 - ON 1)',' ',' ',' ']
 VETO_UNITS      = ['','','','(ms)']
 NONVETO_UNITS   = ['','','(ms)']
